==> emmeans_0.9.tar.gz: emmeans/inst/doc/confidence-intervals.R <==
## ---- echo = FALSE, results = "hide", message = FALSE--------------------
require("emmeans")
knitr::opts_chunk$set(collapse = TRUE, fig.width = 4.5)

## ------------------------------------------------------------------------
pigs.lm <- lm(log(conc) ~ source + factor(percent), data = pigs)
pigs.rg <- ref_grid(pigs.lm)
class(pigs.rg)

pigs.emmGrid.s <- emmeans(pigs.rg, "source")
class(pigs.emmGrid.s)

## ------------------------------------------------------------------------
pigs.rg

pigs.emmGrid.s

## ------------------------------------------------------------------------
str(pigs.emmGrid.s)

## ------------------------------------------------------------------------
class(summary(pigs.emmGrid.s))

## ------------------------------------------------------------------------
test(pigs.emmGrid.s)

## ------------------------------------------------------------------------
test(pigs.emmGrid.s, null = log(40), side = ">")

## ------------------------------------------------------------------------
test(pigs.emmGrid.s, null = log(40), side = ">", type = "response")

## ------------------------------------------------------------------------
confint(pigs.emmGrid.s, side = ">", level = .90, type = "response")

## ------------------------------------------------------------------------
confint(pigs.emmGrid.s, adjust = "tukey")

## ------------------------------------------------------------------------
test(pigs.emmGrid.s, null = log(40), side = ">", adjust = "bonferroni")

## ------------------------------------------------------------------------
confint(pigs.rg, by = "source")

## ----eval = FALSE--------------------------------------------------------
#  emmeans(pigs.lm, ~ percent | source)     ### same results as above
#  summary(.Last.value, by = percent)       ### grouped the other way

## ------------------------------------------------------------------------
pigs.prs.s <- pairs(pigs.emmGrid.s)
pigs.prs.s

## ------------------------------------------------------------------------
test(pigs.prs.s, joint = TRUE)

## ------------------------------------------------------------------------
test(pigs.prs.s, delta = log(1.25), adjust = "none")

==> emmeans_1.0.tar.gz: emmeans/inst/doc/confidence-intervals.R <==
## ---- echo = FALSE, results = "hide", message = FALSE--------------------
require("emmeans")
knitr::opts_chunk$set(collapse = TRUE, fig.width = 4.5)

## ------------------------------------------------------------------------
pigs.lm <- lm(log(conc) ~ source + factor(percent), data = pigs)
pigs.rg <- ref_grid(pigs.lm)
class(pigs.rg)

pigs.emm.s <- emmeans(pigs.rg, "source")
class(pigs.emm.s)

## ------------------------------------------------------------------------
pigs.rg

pigs.emm.s

## ------------------------------------------------------------------------
str(pigs.emm.s)

## ------------------------------------------------------------------------
class(summary(pigs.emm.s))

## ------------------------------------------------------------------------
test(pigs.emm.s)

## ------------------------------------------------------------------------
test(pigs.emm.s, null = log(40), side = ">")

## ------------------------------------------------------------------------
test(pigs.emm.s, null = log(40), side = ">", type = "response")

## ------------------------------------------------------------------------
confint(pigs.emm.s, side = ">", level = .90, type = "response")

## ------------------------------------------------------------------------
confint(pigs.emm.s, adjust = "tukey")

## ------------------------------------------------------------------------
test(pigs.emm.s, null = log(40), side = ">", adjust = "bonferroni")

## ------------------------------------------------------------------------
confint(pigs.rg, by = "source")

## ----eval = FALSE--------------------------------------------------------
#  emmeans(pigs.lm, ~ percent | source)     ### same results as above
#  summary(.Last.value, by = percent)       ### grouped the other way

## ------------------------------------------------------------------------
pigs.prs.s <- pairs(pigs.emm.s)
pigs.prs.s

## ------------------------------------------------------------------------
test(pigs.prs.s, joint = TRUE)

## ------------------------------------------------------------------------
test(pigs.prs.s, delta = log(1.25), adjust = "none")
